Index: chrome/browser/resources/options/autofill_options_list.js |
diff --git a/chrome/browser/resources/options/autofill_options_list.js b/chrome/browser/resources/options/autofill_options_list.js |
index cd3dd261b6df6913bee591154350a168fe1d1030..723c44b551d75926fd069718bd9710d51172992c 100644 |
--- a/chrome/browser/resources/options/autofill_options_list.js |
+++ b/chrome/browser/resources/options/autofill_options_list.js |
@@ -98,14 +98,14 @@ cr.define('options.autofillOptions', function() { |
/** |
* For local Autofill data, this function causes the AutofillOptionsHandler |
* to call showEditAddressOverlay(). For Wallet data, the user is |
* redirected to the Wallet web interface. |
*/ |
loadAddressEditor: function() { |
if (this.metadata_.isLocal) |
chrome.send('loadAddressEditor', [this.metadata_.guid]); |
else |
- window.open(loadTimeData.getString('manageWalletAddressesUrl')); |
+ window.open(loadTimeData.getString('paymentsManageAddressesUrl')); |
}, |
}; |
@@ -171,14 +171,14 @@ cr.define('options.autofillOptions', function() { |
/** |
* For local Autofill data, this function causes the AutofillOptionsHandler |
* to call showEditCreditCardOverlay(). For Wallet data, the user is |
* redirected to the Wallet web interface. |
*/ |
loadCreditCardEditor: function() { |
if (this.metadata_.isLocal) |
chrome.send('loadCreditCardEditor', [this.metadata_.guid]); |
else |
- window.open(loadTimeData.getString('manageWalletPaymentMethodsUrl')); |
+ window.open(loadTimeData.getString('paymentsManageInstrumentsUrl')); |
}, |
}; |
@@ -98,14 +98,14 @@ cr.define('options.autofillOptions', function() { |
/** |
* For local Autofill data, this function causes the AutofillOptionsHandler |
- * to call showEditAddressOverlay(). For Wallet data, the user is |
- * redirected to the Wallet web interface. |
+ * to call showEditAddressOverlay(). For Payments data, the user is |
+ * redirected to the Payments web interface. |
*/ |
loadAddressEditor: function() { |
@@ -171,14 +171,14 @@ cr.define('options.autofillOptions', function() { |
/** |
* For local Autofill data, this function causes the AutofillOptionsHandler |
- * to call showEditCreditCardOverlay(). For Wallet data, the user is |
- * redirected to the Wallet web interface. |
+ * to call showEditCreditCardOverlay(). For Payments data, the user is |
+ * redirected to the Payments web interface. |
*/ |
loadCreditCardEditor: function() { |